==> apache-superset-1.3.0-source.tar.gz: apache-superset-1.3.0rc2/superset-frontend/src/components/OmniContainer/Omnibar.tsx <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import React from 'react';
import OmnibarDeprecated from 'omnibar';

interface Props {
  id: string;
  placeholder: string;
  extensions: ((query: string) => Promise<any>)[];
}

/**
 * @deprecated Component "omnibar" does not support prop className or id (the original implementation used className). However, the original javascript code was sending these prop and was working correctly. lol
 * As this behavior is unpredictable, and does not works whitch types, I have isolated this component so that in the future a better solution can be found and implemented.
 * We need to find a substitute for this component or some way of working around this problem
 */
export function Omnibar({ extensions, placeholder, id }: Props) {
  return (
    <OmnibarDeprecated
      // @ts-ignore
      id={id}
      placeholder={placeholder}
      extensions={extensions}
      // autoFocus // I tried to use this prop (autoFocus) but it only works the first time that Omnibar is shown
    />
  );
}

==> apache-superset-1.5.0-source.tar.gz: apache-superset-1.5.0rc4/superset-frontend/src/components/OmniContainer/Omnibar.tsx <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import React from 'react';
import OmnibarDeprecated from 'omnibar';

interface Props {
  id: string;
  placeholder: string;
  extensions: ((query: string) => Promise<any>)[];
}

/**
 * @deprecated Component "omnibar" does not support prop className or id (the original implementation used className). However, the original javascript code was sending these prop and was working correctly. lol
 * As this behavior is unpredictable, and does not works whitch types, I have isolated this component so that in the future a better solution can be found and implemented.
 * We need to find a substitute for this component or some way of working around this problem
 */
export function Omnibar({ extensions, placeholder, id }: Props) {
  return (
    <OmnibarDeprecated
      // @ts-ignore
      id={id}
      placeholder={placeholder}
      extensions={extensions}
      autoComplete="off"
      autoFocus
    />
  );
}
